@@ -8,6 +8,7 @@
 #include <QApplication>
 #include <QCommandLineOption>
 #include <QCommandLineParser>
+#include <QDBusUnixFileDescriptor>
 #include <QDebug>
 #include <QDir>
 #include <QFile>
@@ -55,7 +56,16 @@ int main(int argc, char **argv)
 
         KAuth::Action action(QStringLiteral("org.kde.kcontrol.kcmsddm.installtheme"));
         action.setHelperId(QStringLiteral("org.kde.kcontrol.kcmsddm"));
-        action.addArgument(QStringLiteral("filePath"), themefile.absoluteFilePath());
+
+        QFile theme(themefile.absoluteFilePath());
+        if (!theme.open(QIODevice::ReadOnly)) {
+            qWarning() << "Unable to open file";
+            return 0;
+        }
+
+        const QDBusUnixFileDescriptor themefileFd(theme.handle());
+
+        action.addArgument(QStringLiteral("filedescriptor"), QVariant::fromValue(themefileFd));
 
         KAuth::ExecuteJob *job = action.execute();
         bool rc = job->exec();
@@ -67,12 +77,12 @@ int main(int argc, char **argv)
             return -1;
         }
 
-        KConfigGroup cg(KSharedConfig::openConfig(QStringLiteral("sddmthemeinstallerrc"), KConfig::SimpleConfig), "DownloadedThemes");
+        KConfigGroup cg(KSharedConfig::openConfig(QStringLiteral("sddmthemeinstallerrc"), KConfig::SimpleConfig), QStringLiteral("DownloadedThemes"));
         cg.writeEntry(themefile.absoluteFilePath(), job->data().value(QStringLiteral("installedPaths")).toStringList());
         return 0;
     }
     if (parser.isSet(QStringLiteral("uninstall"))) {
-        KConfigGroup cg(KSharedConfig::openConfig(QStringLiteral("sddmthemeinstallerrc"), KConfig::SimpleConfig), "DownloadedThemes");
+        KConfigGroup cg(KSharedConfig::openConfig(QStringLiteral("sddmthemeinstallerrc"), KConfig::SimpleConfig), QStringLiteral("DownloadedThemes"));
         const QStringList installed = cg.readEntry(args.first(), QStringList());
         for (const QString &installedTheme : installed) {
             KAuth::Action action(QStringLiteral("org.kde.kcontrol.kcmsddm.uninstalltheme"));
